@@ -573,16 +573,9 @@ public static int identityHashCode(Object anObject) {
 @CallerSensitive
 public static void load(String pathName) {
 	SecurityManager smngr = System.getSecurityManager();
-	if (smngr != null) {
+	if (smngr != null)
 		smngr.checkLink(pathName);
-	}
-	File fileName = new File(pathName);
-	if (fileName.isAbsolute()) {
-		ClassLoader.loadLibrary(getCallerClass(), fileName);
-	} else {
-		// K0648 = Not an absolute path: {0}
-		throw new UnsatisfiedLinkError(com.ibm.oti.util.Msg.getString("K0648", pathName));//$NON-NLS-1$
-	}
+	ClassLoader.loadLibraryWithPath(pathName, ClassLoader.callerClassLoader(), null);
 }
 
 /**
@@ -595,11 +588,7 @@ public static void load(String pathName) {
  */
 @CallerSensitive
 public static void loadLibrary(String libName) {
-	SecurityManager smngr = System.getSecurityManager();
-	if (smngr != null) {
-		smngr.checkLink(libName);
-	}
-	ClassLoader.loadLibrary(getCallerClass(), libName);
+	ClassLoader.loadLibraryWithClassLoader(libName, ClassLoader.callerClassLoader());
 }
 
 /**
